@@ -12,43 +12,49 @@
 # <https://www.gnu.org/licenses/>.
 
 import abc
+import collections
 import enum
-from typing import TypeVar, Union
+from typing import Type, TypeVar, Union, overload
 
 import colour
 from bytesioex import Byte, Int, SByte, UInt
 
+from pyflp._utils import buflen_to_varint
 from pyflp.constants import BYTE, DATA, DATA_TEXT_EVENTS, DWORD, TEXT, WORD
-from pyflp.utils import buflen_to_varint
+
+EventID = TypeVar("EventID", enum.IntEnum, int)
 
 
 class _Event(abc.ABC):
     """Abstract base class representing an event."""
 
-    _count = 0
-
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def size(self) -> int:
         """Raw event size in bytes."""
 
     @property
     def index(self) -> int:
-        return self.__index
+        """Zero based index of instance w.r.t factory."""
+        return self._index
+
+    @property
+    def data(self) -> bytes:
+        return self._data
 
     @abc.abstractmethod
     def dump(self, new_data):
-        """Converts Python data types into bytes
-        objects and dumps them to `self.data`."""
+        """Converts Python types into bytes objects and stores it."""
 
     def to_raw(self) -> bytes:
         """Used by Project.save(). Overriden by `_VariabledSizedEvent`."""
-        return int.to_bytes(self.id, 1, "little") + self.data
+        return int.to_bytes(self.id_, 1, "little") + self.data
 
     def __repr__(self) -> str:
         cls = type(self).__name__
-        sid = str(self.id)
-        iid = int(self.id)
-        if isinstance(self.id, enum.IntEnum):
+        sid = str(self.id_)
+        iid = int(self.id_)
+        if isinstance(self.id_, enum.IntEnum):
             return f"{cls!r} id={sid!r}, {iid!r}"
         return f"{cls!r} id={iid!r}"
 
@@ -57,32 +63,27 @@ class _Event(abc.ABC):
             raise TypeError(
                 f"Cannot compare equality between an 'Event' and {type(o)!r}"
             )
-        return self.id == o.id and self.data == o.data
+        return self.id_ == o.id_ and self.data == o.data
 
     def __ne__(self, o: object) -> bool:
         if not isinstance(o, type(self)):
             raise TypeError(
                 f"Cannot compare inequality between an 'Event' and {type(o)!r}"
             )
-        return self.id != o.id or self.data != o.data
+        return self.id_ != o.id_ or self.data != o.data
 
-    def __init__(self, id: Union[enum.IntEnum, int], data: bytes):
+    def __init__(self, index: int, id: EventID, data: bytes):
         """
         Args:
-            id (Union[enum.IntEnum, int]): An event ID from **0** to **255**.
+            id (EventID): An event ID from **0** to **255**.
             data (bytes): A `bytes` object.
         """
-
-        self.id = id
-        self.data = data
-        self.__index = _Event._count
-        _Event._count += 1
+        self.id_ = id
+        self._data = data
+        self._index = index
         super().__init__()
 
 
-_EventType = TypeVar("_EventType", bound=_Event)
-
-
 class _VariableSizedEvent(_Event):
     """Implements `Event.size` and `Event.to_raw` for `TextEvent` and `DataEvent`."""
 
@@ -94,13 +95,13 @@ class _VariableSizedEvent(_Event):
 
     def __repr__(self) -> str:
         cls = self.__class__.__name__
-        iid = int(self.id)
-        if isinstance(self.id, enum.IntEnum):
-            return f"<{cls!r} id={self.id.name!r} ({iid!r}), size={self.size!r}>"
+        iid = int(self.id_)
+        if isinstance(self.id_, enum.IntEnum):
+            return f"<{cls!r} id={self.id_.name!r} ({iid!r}), size={self.size!r}>"
         return f"<{cls!r} id={iid!r}, size={self.size!r}>"
 
     def to_raw(self) -> bytes:
-        id = int.to_bytes(self.id, 1, "little")
+        id = int.to_bytes(self.id_, 1, "little")
         length = buflen_to_varint(self.data) if self.data else b"\x00"
         data = self.data
         return id + length + data if self.data else id + length
@@ -127,13 +128,13 @@ class _ByteEvent(_Event):
 
         if isinstance(new_data, bool):
             data = 1 if new_data else 0
-            self.data = data.to_bytes(1, "little")
+            self._data = data.to_bytes(1, "little")
         elif isinstance(new_data, bytes):
             if len(new_data) != 1:
                 raise ValueError(
                     f"Expected a bytes object of 1 byte length; got {new_data!r}"
                 )
-            self.data = new_data
+            self._data = new_data
         elif isinstance(new_data, int):
             if new_data != abs(new_data) and new_data not in range(-128, 128):
                 raise OverflowError(
@@ -141,7 +142,7 @@ class _ByteEvent(_Event):
                 )
             elif new_data > 255:
                 raise OverflowError(f"Expected a value from 0 to 255; got {new_data!r}")
-            self.data = new_data.to_bytes(1, "little")
+            self._data = new_data.to_bytes(1, "little")
         else:
             raise TypeError(
                 f"Expected a bytes, bool or an int object; got {type(new_data)!r}"
@@ -158,30 +159,29 @@ class _ByteEvent(_Event):
 
     def __repr__(self) -> str:
         b = self.to_int8()
-        B = self.to_uint8()
+        B = self.to_uint8()  # noqa
         if b == B:
             msg = f"B={B!r}"
         else:
             msg = f"b={b!r}, B={B!r}"
         return f"<{super().__repr__()!r}, {msg!r}>"
 
-    def __init__(self, id: Union[enum.IntEnum, int], data: bytes):
+    def __init__(self, index: int, id: EventID, data: bytes):
         """
         Args:
-            id (Union[enum.IntEnum, int]): An event ID from **0** to **63**.
+            id (EventID): An event ID from **0** to **63**.
             data (bytes): A 1 byte sized `bytes` object.
 
         Raises:
             ValueError: When `id` is not in range of 0-63.
             TypeError: When size of `data` is not 1.
         """
-
         if not (id < WORD and id >= BYTE):
             raise ValueError(f"Exepcted 0-63; got {id!r}")
         dl = len(data)
         if dl != 1:
             raise TypeError(f"Unexpected data size; expected 1, got {dl!r}")
-        super().__init__(id, data)
+        super().__init__(index, id, data)
 
 
 class _WordEvent(_Event):
@@ -202,20 +202,19 @@ class _WordEvent(_Event):
             OverflowError: When `new_data` cannot be accumulated in 2 bytes.
             TypeError: When `new_data` isn't an int or a bytes object.
         """
-
         word = new_data
         if isinstance(word, bytes):
             if len(word) != 2:
                 raise ValueError(
                     f"Expected a bytes object of 2 bytes length; got {word!r}"
                 )
-            self.data = word
+            self._data = word
         elif isinstance(word, int):
             if word != abs(word) and word not in range(-32768, 32768):
                 raise OverflowError(f"Expected a value -32768 to 32767; got {word!r}")
             elif word > 65535:
                 raise OverflowError(f"Expected a value of 0 to 65535; got {word!r}")
-            self.data = word.to_bytes(2, "little")
+            self._data = word.to_bytes(2, "little")
         else:
             raise TypeError(f"Expected a bytes or an int object; got {type(word)!r}")
 
@@ -227,31 +226,30 @@ class _WordEvent(_Event):
 
     def __repr__(self) -> str:
         h = self.to_int16()
-        H = self.to_uint16()
+        H = self.to_uint16()  # noqa
         if h == H:
             msg = f"H={H!r}"
         else:
             msg = f"h={h!r}, H={H!r}"
         return f"<{super().__repr__()!r}, {msg!r}>"
 
-    def __init__(self, id: Union[enum.IntEnum, int], data: bytes):
+    def __init__(self, index: int, id: EventID, data: bytes):
         """
         Args:
-            id (Union[enum.IntEnum, int]): An event ID from **64** to **127**.
+            id (EventID): An event ID from **64** to **127**.
             data (bytes): A `bytes` object of size 2.
 
         Raises:
             ValueError: When `id` is not in range of 64-127.
             TypeError: When size of `data` is not 2.
         """
-
         if id not in range(WORD, DWORD):
             raise ValueError(f"Exepcted 64-127; got {id!r}")
         if len(data) != 2:
             raise TypeError(
                 f"Expected a data of 2 bytes; got a data of size {len(data)!r} instead"
             )
-        super().__init__(id, data)
+        super().__init__(index, id, data)
 
 
 class _DWordEvent(_Event):
@@ -283,7 +281,7 @@ class _DWordEvent(_Event):
                 raise ValueError(
                     f"Expected a bytes object of 4 bytes length; got {dword!r}"
                 )
-            self.data = dword
+            self._data = dword
         elif isinstance(dword, int):
             if dword != abs(dword) and dword not in range(
                 self.INT_MIN, self.INT_MAX + 1
@@ -296,7 +294,7 @@ class _DWordEvent(_Event):
                 raise OverflowError(
                     f"Expected a value of 0 to {self.DWORD_MAX!r}; got {dword!r}"
                 )
-            self.data = dword.to_bytes(4, "little")
+            self._data = dword.to_bytes(4, "little")
         else:
             raise TypeError(f"Expected a bytes or an int object; got {type(dword)!r}")
 
@@ -317,26 +315,22 @@ class _DWordEvent(_Event):
             msg = f"i={i32!r}, I={u32!r}"
         return f"<{super().__repr__()!r}, {msg!r}>"
 
-    def __init__(self, id: Union[enum.IntEnum, int], data: bytes):
+    def __init__(self, index: int, id: EventID, data: bytes):
         """
         Args:
-            id (Union[enum.IntEnum, int]): An event ID from **128** to **191**.
+            id (EventID): An event ID from **128** to **191**.
             data (bytes): A `bytes` object of size 4.
 
         Raises:
             ValueError: When `id` is not in range of 128-191.
             TypeError: When size of `data` is not 4.
         """
-
         if id not in range(DWORD, TEXT):
             raise ValueError(f"Exepcted 128-191; got {id!r}")
         dl = len(data)
         if dl != 4:
             raise TypeError(f"Unexpected data size; expected 4, got {dl!r}")
-        super().__init__(id, data)
-
-
-_DWordEventType = TypeVar("_DWordEventType", bound=_DWordEvent)
+        super().__init__(index, id, data)
 
 
 class _ColorEvent(_DWordEvent):
@@ -353,7 +347,7 @@ class _ColorEvent(_DWordEvent):
 
         if not isinstance(new_color, colour.Color):
             raise TypeError(f"Expected a colour.Color; got {type(new_color)!r}")
-        self.data = bytes((int(c * 255) for c in new_color.rgb)) + b"\x00"
+        self._data = bytes((int(c * 255) for c in new_color.rgb)) + b"\x00"
 
     def to_color(self) -> colour.Color:
         r, g, b = (c / 255 for c in self.data[:3])
@@ -363,8 +357,6 @@ class _ColorEvent(_DWordEvent):
 class _TextEvent(_VariableSizedEvent):
     """Represents a variable sized event used for storing strings."""
 
-    uses_unicode = True  # Parser can change this
-
     @staticmethod
     def as_ascii(buf: bytes):
         return buf.decode("ascii", errors="ignore").strip("\0")
@@ -389,23 +381,29 @@ class _TextEvent(_VariableSizedEvent):
         if not isinstance(text, str):
             raise TypeError(f"Expected an str object; got {type(text)!r}")
         # Version event (199) is always ASCII
-        if _TextEvent.uses_unicode and self.id != 199:
-            self.data = text.encode("utf-16", errors="ignore") + b"\0\0"
+        if self._uses_unicode and self.id_ != 199:
+            self._data = text.encode("utf-16-le") + b"\0\0"
         else:
-            self.data = text.encode("ascii", errors="ignore") + b"\0"
+            self._data = text.encode("ascii") + b"\0"
 
     def to_str(self) -> str:
-        if _TextEvent.uses_unicode and self.id != 199:
+        if self._uses_unicode and self.id_ != 199:
             return self.as_uf16(self.data)
         return self.as_ascii(self.data)
 
     def __repr__(self) -> str:
         return f'<{super().__repr__().strip("<>")!r}, s="{self.to_str()!r}">'
 
-    def __init__(self, id: Union[enum.IntEnum, int], data: bytes):
+    def __init__(
+        self,
+        index: int,
+        id: EventID,
+        data: bytes,
+        uses_unicode: bool = True,
+    ):
         """
         Args:
-            id (Union[enum.IntEnum, int]): An event ID from \
+            id (EventID): An event ID from
                 **192** to **207** or in `DATA_TEXT_EVENTS`.
             data (bytes): A `bytes` object.
 
@@ -417,7 +415,8 @@ class _TextEvent(_VariableSizedEvent):
             raise ValueError(f"Unexpected ID: {id!r}")
         if not isinstance(data, bytes):
             raise TypeError(f"Expected a bytes object; got {type(data)!r}")
-        super().__init__(id, data)
+        super().__init__(index, id, data)
+        self._uses_unicode = uses_unicode
 
 
 class _DataEvent(_VariableSizedEvent):
@@ -427,9 +426,8 @@ class _DataEvent(_VariableSizedEvent):
     The task of parsing is completely handled by one of the FLObject subclasses,
     hence no `to_*` conversion method is provided."""
 
-    _chunk_size = None
-    """Used by subclasses. Parsing is cancelled if this is
-    not equal to size of bytes passed to `__init__`."""
+    CHUNK_SIZE = None
+    """Parsing is not done if size of `data` argument is not equal to this."""
 
     def dump(self, new_bytes: bytes):
         """Dumps a blob of bytes to event data as is; no conversions of any-type.
@@ -447,26 +445,80 @@ class _DataEvent(_VariableSizedEvent):
             raise TypeError(
                 f"Expected a bytes object; got a {type(new_bytes)!r} object"
             )
-        self.data = new_bytes
+        self._data = new_bytes
 
-    def __init__(self, id: Union[enum.IntEnum, int], data: bytes):
+    def __init__(self, index: int, id: EventID, data: bytes):
         """
         Args:
-            id (Union[enum.IntEnum, int]): An event ID in from **208** to **255**.
+            id (EventID): An event ID in from **208** to **255**.
             data (bytes): A `bytes` object.
 
         Raises:
             ValueError: When the event ID is not in the range of 208 (`DATA`) to 255.
         """
-
         if id < DATA:
             raise ValueError(f"Expected an event ID from 209 to 255; got {id!r}")
         if not isinstance(data, bytes):
             raise TypeError(f"Expected a bytes object; got {type(data)!r}")
-        super().__init__(id, data)
-        if self._chunk_size is not None:  # pragma: no cover
-            if len(data) != self._chunk_size:
+        super().__init__(index, id, data)
+        if self.CHUNK_SIZE is not None:  # pragma: no cover
+            if len(data) != self.CHUNK_SIZE:
                 return
 
 
-_DataEventType = TypeVar("_DataEventType", bound=_DataEvent)
+EventType = TypeVar("EventType", bound=_Event)
+DWordEventType = TypeVar("DWordEventType", bound=_DWordEvent)
+DataEventType = TypeVar("DataEventType", bound=_DataEvent)
+
+
+class EventList(collections.UserList):
+    def append(self, event_t: Type[_Event], id_: EventID, data: bytes, *args) -> None:
+        """Create and append an event to the list."""
+        event = self.create(event_t, id_, data, *args)
+        super().append(event)
+
+    def append_event(self, event: EventType) -> None:
+        """For use with `create`."""
+        super().append(event)
+
+    @overload
+    def create(
+        self, event_t: Type[_ByteEvent], id_: EventID, data: bytes, *args
+    ) -> _ByteEvent:
+        ...
+
+    @overload
+    def create(
+        self, event_t: Type[_WordEvent], id_: EventID, data: bytes, *args
+    ) -> _WordEvent:
+        ...
+
+    @overload
+    def create(
+        self, event_t: Type[_ColorEvent], id_: EventID, data: bytes, *args
+    ) -> _ColorEvent:
+        ...
+
+    @overload
+    def create(
+        self, event_t: Type[_DWordEvent], id_: EventID, data: bytes, *args
+    ) -> _DWordEvent:
+        ...
+
+    @overload
+    def create(
+        self, event_t: Type[_TextEvent], id_: EventID, data: bytes, *args
+    ) -> _TextEvent:
+        ...
+
+    @overload
+    def create(
+        self, event_t: Type[_DataEvent], id_: EventID, data: bytes, *args
+    ) -> _DataEvent:
+        ...
+
+    def create(
+        self, event_t: Type[_Event], id_: EventID, data: bytes, *args
+    ) -> EventType:
+        """Create an event object and return it."""
+        return event_t(len(self.data), id_, data, *args)
