@@ -15,7 +15,7 @@ from typing import Any, Optional
 
 from bytesioex import BytesIOEx
 
-from pyflp._event import _DataEvent
+from pyflp._event import EventID, _DataEvent
 from pyflp._flobject import _FLObject
 from pyflp._properties import _IntProperty
 
@@ -25,12 +25,10 @@ __all__ = ["ChannelDelay", "ChannelDelayEvent"]
 class ChannelDelayEvent(_DataEvent):
     """Implements `Channel.EventID.Delay`."""
 
-    _chunk_size = 20
+    CHUNK_SIZE = 20
 
-    def __init__(self, data: bytes):
-        from pyflp.channel.channel import Channel
-
-        super().__init__(Channel.EventID.Delay, data)
+    def __init__(self, index: int, id_: EventID, data: bytes) -> None:
+        super().__init__(index, id_, data)
         self.__r = r = BytesIOEx(data)
         self.feedback = r.read_I()
         self.pan = r.read_I()
