@@ -17,15 +17,14 @@ DWORD = 128
 TEXT = 192
 DATA = 208
 
-DATA_TEXT_EVENTS = (
-    TEXT + 49,  # ArrangementEventID.Name
-    TEXT + 39,  # FilterChannelEventID.Name
-    TEXT + 47,  # TrackEventID.Name
-)
-"""TextEvents occupying event ID space used by DataEvents"""
-
 HEADER_MAGIC = b"FLhd"
 HEADER_SIZE = 6
 DATA_MAGIC = b"FLdt"
-
 VALID_PPQS = (24, 48, 72, 96, 120, 144, 168, 192, 384, 768, 960)
+
+DATA_TEXT_EVENTS = (
+    TEXT + 49,  # Arrangement.EventID.Name
+    TEXT + 39,  # FilterChannel.EventID.Name
+    TEXT + 47,  # Track.EventID.Name
+)
+"""`TextEvent`s occupying event ID space used by `DataEvent`s"""
