@@ -16,8 +16,8 @@ from typing import List, Optional
 
 import colour
 
-from pyflp._event import _DataEventType, _DWordEvent, _EventType, _TextEvent, _WordEvent
-from pyflp._flobject import _MaxInstancedFLObject
+from pyflp._event import DataEventType, EventType, _DWordEvent, _TextEvent, _WordEvent
+from pyflp._flobject import MaxInstances, _FLObject
 from pyflp._properties import _ColorProperty, _IntProperty, _StrProperty, _UIntProperty
 from pyflp._validators import _IntValidator, _UIntValidator
 from pyflp.constants import DATA, DWORD, TEXT, WORD
@@ -25,10 +25,8 @@ from pyflp.insert.parameters import InsertFlags, InsertParameters
 from pyflp.insert.slot import InsertSlot
 
 
-class Insert(_MaxInstancedFLObject):
-    # Parser will decide a value for max_count
-
-    class EQ(_MaxInstancedFLObject):
+class Insert(_FLObject):
+    class EQ(_FLObject):
         """Insert post EQ.
 
         [Manual](https://www.image-line.com/fl-studio-learning/fl-studio-online-manual/html/mixer_trackprops.htm)
@@ -158,8 +156,9 @@ class Insert(_MaxInstancedFLObject):
 
     @route_volumes.setter
     def route_volumes(self, value: List[int]):
-        if len(value) != Insert.max_count:
-            raise ValueError(f"Expected a list of size {Insert.max_count}")
+        num_inserts = self._max_instances.inserts
+        if len(value) != num_inserts:
+            raise ValueError(f"Expected a list of size {num_inserts}")
         self._route_volumes = value
 
     @property
@@ -177,13 +176,13 @@ class Insert(_MaxInstancedFLObject):
             self._parameters.flags &= ~InsertFlags.Locked
 
     # * Parsing logic
-    def parse_event(self, e: _EventType) -> None:
-        if e.id == InsertSlot.EventID.Index:
+    def parse_event(self, e: EventType) -> None:
+        if e.id_ == InsertSlot.EventID.Index:
             self._cur_slot.parse_event(e)
             self._slots.append(self._cur_slot)
-            if len(self._slots) < InsertSlot.max_count:
+            if len(self._slots) < self._max_instances.slots:
                 self._cur_slot = InsertSlot()
-        elif e.id in (
+        elif e.id_ in (
             InsertSlot.EventID.Color,
             InsertSlot.EventID.Icon,
             InsertSlot.EventID.PluginNew,
@@ -196,44 +195,43 @@ class Insert(_MaxInstancedFLObject):
             return super().parse_event(e)
 
     def _parse_word_event(self, e: _WordEvent):
-        if e.id == Insert.EventID.Icon:
+        if e.id_ == Insert.EventID.Icon:
             self._parse_H(e, "icon")
 
     def _parse_dword_event(self, e: _DWordEvent):
-        if e.id == Insert.EventID.Input:
+        if e.id_ == Insert.EventID.Input:
             self._parse_i(e, "input")
-        elif e.id == Insert.EventID.Color:
+        elif e.id_ == Insert.EventID.Color:
             self._parse_color(e, "color")
-        elif e.id == Insert.EventID.Output:
+        elif e.id_ == Insert.EventID.Output:
             self._parse_i(e, "output")
 
     def _parse_text_event(self, e: _TextEvent):
-        if e.id == Insert.EventID.Name:
+        if e.id_ == Insert.EventID.Name:
             self._parse_s(e, "name")
 
-    def _parse_data_event(self, e: _DataEventType):
-        if e.id == Insert.EventID.Parameters:
+    def _parse_data_event(self, e: DataEventType):
+        if e.id_ == Insert.EventID.Parameters:
             self._events["parameters"] = e
             self._parameters = InsertParameters()
             self._parameters.parse_event(e)
-        elif e.id == Insert.EventID.Routing:
+        elif e.id_ == Insert.EventID.Routing:
             routing = []
             for byte in e.data:
                 route = True if byte > 0 else False
                 routing.append(route)
             self._parseprop(e, "routing", routing)
 
-    def _save(self) -> List[_EventType]:
+    def _save(self) -> List[EventType]:
         events = list(super()._save())
         for slot in self.slots:
             events.extend(slot._save())
         return events
 
-    def __init__(self):
-        super().__init__()
-        InsertSlot._count = Insert.EQ._count = 0
+    def __init__(self, project, max_instances: MaxInstances):
+        super().__init__(project, max_instances)
         self._slots: List[InsertSlot] = []
         self._cur_slot = InsertSlot()
         self._eq = Insert.EQ()
-        self._route_volumes = [int()] * Insert.max_count
-        self.index = Insert._count - 2
+        self._route_volumes: List[int] = []
+        self.index = len(project.inserts) - 1
