@@ -16,8 +16,8 @@ from typing import Optional, ValuesView
 
 import colour
 
-from pyflp._event import _DataEvent, _DWordEventType, _EventType, _TextEvent, _WordEvent
-from pyflp._flobject import _MaxInstancedFLObject
+from pyflp._event import DWordEventType, EventType, _DataEvent, _TextEvent, _WordEvent
+from pyflp._flobject import _FLObject
 from pyflp._properties import (
     _BoolProperty,
     _ColorProperty,
@@ -33,12 +33,11 @@ from pyflp.plugin.effects.notebook2 import FNoteBook2
 from pyflp.plugin.effects.send import FSend
 from pyflp.plugin.effects.soft_clipper import FSoftClipper
 from pyflp.plugin.effects.soundgoodizer import Soundgoodizer
+from pyflp.plugin.effects.stereo_enhancer import FStereoEnhancer
 from pyflp.plugin.vst import VSTPlugin
 
 
-class InsertSlot(_MaxInstancedFLObject):
-    max_count = 10  # TODO: Older versions had 8, maybe lesser as well
-
+class InsertSlot(_FLObject):
     @enum.unique
     class EventID(enum.IntEnum):
         """Event IDs used by `InsertSlot`."""
@@ -76,7 +75,7 @@ class InsertSlot(_MaxInstancedFLObject):
     color: Optional[colour.Color] = _ColorProperty()
     """Color."""
 
-    index: Optional[int] = _UIntProperty(max_=max_count)
+    index: Optional[int] = _UIntProperty()
     """Index (FL12.3+); occurs irrespective of whether slot is used or not."""
 
     enabled: Optional[bool] = _BoolProperty()
@@ -110,27 +109,27 @@ class InsertSlot(_MaxInstancedFLObject):
 
     # * Parsing logic
     def _parse_word_event(self, e: _WordEvent) -> None:
-        if e.id == InsertSlot.EventID.Index:
+        if e.id_ == InsertSlot.EventID.Index:
             self._parse_H(e, "index")
 
-    def _parse_dword_event(self, e: _DWordEventType):
-        if e.id == InsertSlot.EventID.Color:
+    def _parse_dword_event(self, e: DWordEventType):
+        if e.id_ == InsertSlot.EventID.Color:
             self._parse_color(e, "color")
-        elif e.id == InsertSlot.EventID.Icon:
+        elif e.id_ == InsertSlot.EventID.Icon:
             self._parse_I(e, "icon")
 
     def _parse_text_event(self, e: _TextEvent):
-        if e.id == InsertSlot.EventID.DefaultName:
+        if e.id_ == InsertSlot.EventID.DefaultName:
             self._parse_s(e, "default_name")
-        elif e.id == InsertSlot.EventID.Name:
+        elif e.id_ == InsertSlot.EventID.Name:
             self._parse_s(e, "name")
 
     def _parse_data_event(self, e: _DataEvent):
-        if e.id == InsertSlot.EventID.PluginNew:
+        if e.id_ == InsertSlot.EventID.PluginNew:
             self._events["new"] = e
             self._new = e.data
             # TODO: Parsing similar to ChannelEventID.New (same IDs)
-        elif e.id == InsertSlot.EventID.Plugin:
+        elif e.id_ == InsertSlot.EventID.Plugin:
             n = self.default_name
             if n == "Fruity Soft Clipper":
                 plugin = FSoftClipper()
@@ -140,6 +139,8 @@ class InsertSlot(_MaxInstancedFLObject):
                 plugin = FBalance()
             elif n == "Soundgoodizer":
                 plugin = Soundgoodizer()
+            elif n == "Fruity Stereo Enhancer":
+                plugin = FStereoEnhancer()
             elif n == "Fruity Fast Dist":
                 plugin = FFastDist()
             elif n == "Fruity Send":
@@ -150,7 +151,7 @@ class InsertSlot(_MaxInstancedFLObject):
                 plugin = _Plugin()
             self._parse_flobject(e, "plugin", plugin)
 
-    def _save(self) -> ValuesView[_EventType]:
+    def _save(self) -> ValuesView[EventType]:
         events = super()._save()
 
         new_event = self._events.get("new")
